@@ -429,6 +429,11 @@ display_alloc_init (gboolean missing_p, GGobiData * d, ggobid * gg)
   return (display);
 }
 
+static void
+display_destroy_cb(displayd *display, ggobid *gg)
+{
+  display_free(display, true, gg);
+}
 
 gint
 display_add (displayd * display, ggobid * gg)
@@ -458,9 +463,14 @@ display_add (displayd * display, ggobid * gg)
   if (GGOBI_IS_WINDOW_DISPLAY (display)
       && GGOBI_WINDOW_DISPLAY (display)->useWindow) {
     GGobi_widget_set (GGOBI_WINDOW_DISPLAY (display)->window, gg, true);
-    if (g_list_length (display->splots))
+  } 
+  
+  g_signal_connect(G_OBJECT(display), "destroy", 
+      G_CALLBACK(display_destroy_cb), gg);
+  
+  if (g_list_length (display->splots))
       display_set_current (display, gg);  /*-- this initializes the mode --*/
-  }
+  
   gg->displays = g_list_append (gg->displays, (gpointer) display);
 
   /* If the tree of displays is active, add this to it. */
@@ -492,7 +502,6 @@ display_add (displayd * display, ggobid * gg)
   return (g_list_length (gg->displays));
 }
 
-
 /*
  * Remove display from the linked list of displays.  Reset
  * current_display and current_splot if necessary.
@@ -579,7 +588,10 @@ display_free (displayd * display, gboolean force, ggobid * gg)
 
     count = g_list_length (display->splots);
 
-    if (GGOBI_IS_WINDOW_DISPLAY (display)) {
+    g_signal_handlers_disconnect_by_func(G_OBJECT(display), 
+        display_destroy_cb, gg); /* don't recurse */
+
+    if (GGOBI_IS_WINDOW_DISPLAY (display) && GGOBI_WINDOW_DISPLAY(display)->useWindow) {
 /*XX
       GList *l;
       for (l=display->splots; count > 0 && l; l=l->next, count--) {
@@ -587,8 +599,9 @@ display_free (displayd * display, gboolean force, ggobid * gg)
         splot_free (sp, display, gg);
       }
 */
-
       gtk_widget_destroy (GGOBI_WINDOW_DISPLAY (display)->window);
+    } else {
+      gtk_widget_destroy(GTK_WIDGET(display));
     }
   }
 
